# check_internet_speed
Check Internet Speed




```
aws s3 bucket cli

upload, download, check file availability, and get all available list from AWS s3 bucket.
```


## Package Installation : 
```
pip install check-internet-speed
```
[Pypi Package Link](https://pypi.org/project/check-internet-speed/)


## How to import the module:
```python
from check_internet_speed.check_internet_speed import check_internet_speed

status = check_internet_speed()

print(status)
```





## License:
MIT Licensed

## Author:
Sujit Mandal

[GitHub](https://github.com/sujitmandal)

[PyPi](https://pypi.org/user/sujitmandal/)

[LinkedIn](https://www.linkedin.com/in/sujit-mandal-91215013a/)
